<?php
/**
 * A PNG image generator
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PngImage extends BaseImage {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this image class
	 *
	 * @param	$templateInstance	A template instance
	 * @return	$imageInstance		An instance of this image class
	 */
	public static final function createPngImage(CompileableTemplate $templateInstance) {
		// Get a new instance
		$imageInstance = new PngImage();

		// Set template instance
		$imageInstance->setTemplateInstance($templateInstance);

		// Set image type
		$imageInstance->setImageType('png');

		// Return the instance
		return $imageInstance;
	}

	/**
	 * Finish this image by producing it
	 *
	 * @return	void
	 */
	public function finishImage () {
		// Call parent method
		parent::finishImage();

		// Get a file name for our image
		$cacheFile = $this->getTemplateInstance()->getImageCacheFqfn();

		// Does it exist?
		if (file_exists($cacheFile)) {
			// Remove it
			@unlink($cacheFile);
		} // END - if

		// Finish the image and send it to a cache file
		imagepng($this->getImageResource(), $cacheFile, 9, PNG_ALL_FILTERS);
	}
}

// [EOF]
?>
